@@ -73,6 +73,9 @@ constexpr auto networkProxyPasswordKeychainKeySuffixC = "_proxy_password";
 constexpr auto legacyRelativeConfigLocationC = "/ownCloud/owncloud.cfg";
 constexpr auto legacyCfgFileNameC = "owncloud.cfg";
 
+constexpr auto unbrandedRelativeConfigLocationC = "/Nextcloud/nextcloud.cfg";
+constexpr auto unbrandedCfgFileNameC = "nextcloud.cfg";
+
 // The maximum versions that this client can read
 constexpr auto maxAccountsVersion = 2;
 constexpr auto maxAccountVersion = 1;
@@ -170,7 +173,8 @@ bool AccountManager::restoreFromLegacySettings()
     // try to open the correctly themed settings
     auto settings = ConfigFile::settingsWithGroup(Theme::instance()->appName());
 
-    auto displayMessageBoxWarning = false;
+    auto wasLegacyImportDialogDisplayed = false;
+    const auto displayLegacyImportDialog = Theme::instance()->displayLegacyImportDialog();
 
     // if the settings file could not be opened, the childKeys list is empty
     // then try to load settings from a very old place
@@ -191,10 +195,16 @@ bool AccountManager::restoreFromLegacySettings()
         const auto legacyCfgFileNamePath = QString(QStringLiteral("/") + legacyCfgFileNameC);
         const auto legacyCfgFileRelativePath = QString(legacyRelativeConfigLocationC);
 
-        const auto legacyLocations = QVector<QString>{legacy2_4CfgFileParentFolder + legacyCfgFileRelativePath,
-                                                      legacy2_5CfgFileParentFolder + legacyCfgFileRelativePath,
-                                                      legacyCfgFileParentFolder + legacyCfgFileNamePath,
-                                                      legacyCfgFileGrandParentFolder + legacyCfgFileRelativePath};
+        auto legacyLocations = QVector<QString>{legacy2_4CfgFileParentFolder + legacyCfgFileRelativePath,
+                                                legacy2_5CfgFileParentFolder + legacyCfgFileRelativePath,
+                                                legacyCfgFileParentFolder + legacyCfgFileNamePath,
+                                                legacyCfgFileGrandParentFolder + legacyCfgFileRelativePath};
+
+        if (Theme::instance()->isBranded()) {
+            const auto unbrandedCfgFileNamePath = QString(QStringLiteral("/") + unbrandedCfgFileNameC);
+            const auto unbrandedCfgFileRelativePath = QString(unbrandedRelativeConfigLocationC);
+            legacyLocations.append({legacyCfgFileParentFolder + unbrandedCfgFileNamePath, legacyCfgFileGrandParentFolder + unbrandedCfgFileRelativePath});
+        }
 
         for (const auto &configFile : legacyLocations) {
             auto oCSettings = std::make_unique<QSettings>(configFile, QSettings::IniFormat);
@@ -206,10 +216,11 @@ bool AccountManager::restoreFromLegacySettings()
             oCSettings->beginGroup(QLatin1String(accountsC));
             const auto accountsListSize = oCSettings->childGroups().size();
             oCSettings->endGroup();
-            if (const QFileInfo configFileInfo(configFile); configFileInfo.exists() && configFileInfo.isReadable()) {
-                displayMessageBoxWarning = true;
+            if (const QFileInfo configFileInfo(configFile);
+                configFileInfo.exists() && configFileInfo.isReadable()) {
                 qCInfo(lcAccountManager) << "Migrate: checking old config " << configFile;
-                if (!forceLegacyImport() && accountsListSize > 0) {
+                if (!forceLegacyImport() && accountsListSize > 0 && displayLegacyImportDialog) {
+                    wasLegacyImportDialogDisplayed = true;
                     const auto importQuestion = accountsListSize > 1
                         ? tr("%1 accounts were detected from a legacy desktop client.\n"
                              "Should the accounts be imported?").arg(QString::number(accountsListSize))
@@ -282,7 +293,7 @@ bool AccountManager::restoreFromLegacySettings()
         return true;
     }
 
-    if (displayMessageBoxWarning) {
+    if (wasLegacyImportDialogDisplayed) {
         QMessageBox::information(nullptr,
                                  tr("Legacy import"),
                                  tr("Could not import accounts from legacy client configuration."));
