@@ -56,7 +56,9 @@ class User : public QObject
     Q_PROPERTY(QString statusMessage READ statusMessage NOTIFY statusChanged)
     Q_PROPERTY(bool desktopNotificationsAllowed READ isDesktopNotificationsAllowed NOTIFY desktopNotificationsAllowedChanged)
     Q_PROPERTY(bool hasLocalFolder READ hasLocalFolder NOTIFY hasLocalFolderChanged)
-    Q_PROPERTY(bool serverHasTalk READ serverHasTalk NOTIFY serverHasTalkChanged)
+    Q_PROPERTY(bool isFeaturedAppEnabled READ isFeaturedAppEnabled NOTIFY featuredAppChanged)
+    Q_PROPERTY(QString featuredAppIcon READ featuredAppIcon NOTIFY featuredAppChanged)
+    Q_PROPERTY(QString featuredAppAccessibleName READ featuredAppAccessibleName NOTIFY featuredAppChanged)
     Q_PROPERTY(QString avatar READ avatarUrl NOTIFY avatarChanged)
     Q_PROPERTY(bool isConnected READ isConnected NOTIFY accountStateChanged)
     Q_PROPERTY(UnifiedSearchResultsListModel* unifiedSearchResultsListModel READ getUnifiedSearchResultsListModel CONSTANT)
@@ -74,15 +76,18 @@ public:
     [[nodiscard]] Folder *getFolder() const;
     ActivityListModel *getActivityModel();
     [[nodiscard]] UnifiedSearchResultsListModel *getUnifiedSearchResultsListModel() const;
-    void openLocalFolder();
+    void openLocalFolder() const;
     void openFolderLocallyOrInBrowser(const QString &fullRemotePath);
     [[nodiscard]] QString name() const;
     [[nodiscard]] QString server(bool shortened = true) const;
     [[nodiscard]] bool hasLocalFolder() const;
-    [[nodiscard]] bool serverHasTalk() const;
+    [[nodiscard]] bool isFeaturedAppEnabled() const;
+    [[nodiscard]] QString featuredAppIcon() const;
+    [[nodiscard]] QString featuredAppAccessibleName() const;
     [[nodiscard]] bool serverHasUserStatus() const;
     [[nodiscard]] AccountApp *talkApp() const;
     [[nodiscard]] bool hasActivities() const;
+    [[nodiscard]] bool isNcAssistantEnabled() const;
     [[nodiscard]] QColor accentColor() const;
     [[nodiscard]] QColor headerColor() const;
     [[nodiscard]] QColor headerTextColor() const;
@@ -103,7 +108,7 @@ public:
 signals:
     void nameChanged();
     void hasLocalFolderChanged();
-    void serverHasTalkChanged();
+    void featuredAppChanged();
     void avatarChanged();
     void accountStateChanged();
     void statusChanged();
@@ -168,6 +173,8 @@ private:
 
     void checkAndRemoveSeenActivities(const ActivityList &list, const int numTalkNotificationsReceived);
 
+    [[nodiscard]] bool serverHasTalk() const;
+
     AccountStatePtr _account;
     bool _isCurrentUser;
     ActivityListModel *_activityModel;
@@ -248,9 +255,9 @@ signals:
 public slots:
     void fetchCurrentActivityModel();
     void openCurrentAccountLocalFolder();
-    void openCurrentAccountTalk();
     void openCurrentAccountServer();
     void openCurrentAccountFolderFromTrayInfo(const QString &fullRemotePath);
+    void openCurrentAccountFeaturedApp();
     void setCurrentUserId(const int id);
     void login(const int id);
     void logout(const int id);
@@ -269,11 +276,16 @@ private:
     void buildUserList();
 };
 
-class ImageProvider : public QQuickImageProvider
+class ImageProvider : public QQuickAsyncImageProvider
 {
+    Q_OBJECT
+
 public:
-    ImageProvider();
-    QImage requestImage(const QString &id, QSize *size, const QSize &requestedSize) override;
+    ImageProvider() = default;
+    QQuickImageResponse *requestImageResponse(const QString &id, const QSize &requestedSize) override;
+
+private:
+    QThreadPool _pool;
 };
 
 class UserAppsModel : public QAbstractListModel
