@@ -21,6 +21,7 @@
 #include <QSslKey>
 #include <QSslCertificate>
 
+#include "libsync/configfile.h"
 #include "networkjobs.h"
 #include "wizard/owncloudwizardcommon.h"
 #include "accountfwd.h"
@@ -64,6 +65,7 @@ public:
     [[nodiscard]] QString ocUrl() const;
     [[nodiscard]] QString localFolder() const;
     [[nodiscard]] QStringList selectiveSyncBlacklist() const;
+    [[nodiscard]] bool useFlow2() const;
     [[nodiscard]] bool useVirtualFileSync() const;
     [[nodiscard]] bool isConfirmBigFolderChecked() const;
 
@@ -108,9 +110,12 @@ signals:
     void needCertificate();
     void styleChanged();
     void onActivate();
+    void wizardClosed();
 
 protected:
     void changeEvent(QEvent *) override;
+    void hideEvent(QHideEvent *) override;
+    void closeEvent(QCloseEvent *) override;
 
 private:
     void customizeStyle();
@@ -131,6 +136,8 @@ private:
 
     bool _registration = false;
 
+    bool _useFlow2 = ConfigFile().forceLoginV2();
+
     friend class OwncloudSetupWizard;
 };
 
