@@ -181,6 +181,12 @@ void FolderMetadata::setupExistingMetadata(const QByteArray &metadata)
         }
     }
 
+    if (_initialSignature.isEmpty()) {
+        qCDebug(lcCseMetadata()) << "Signature is empty";
+        _account->reportClientStatus(OCC::ClientStatusReportingStatus::E2EeError_GeneralError);
+        return;
+    }
+
     if (!parseFileDropPart(metaDataDoc)) {
         qCDebug(lcCseMetadata()) << "Could not parse filedrop part";
         return;
@@ -599,7 +605,7 @@ QByteArray FolderMetadata::encryptedMetadata()
 
     QJsonObject files, folders;
     for (auto it = _files.constBegin(), end = _files.constEnd(); it != end; ++it) {
-        const auto file = convertFileToJsonObject(it);
+        const auto file = convertFileToJsonObject(&(*it));
         if (file.isEmpty()) {
             qCDebug(lcCseMetadata) << "Metadata generation failed for file" << it->encryptedFilename;
             return {};
