@@ -172,9 +172,19 @@ void SyncFileStatusTracker::slotPathTouched(const QString &fileName)
 void SyncFileStatusTracker::slotAddSilentlyExcluded(const QString &folderPath)
 {
     _syncProblems[folderPath] = SyncFileStatus::StatusExcluded;
+    _syncSilentExcludes[folderPath] = SyncFileStatus::StatusExcluded;
     emit fileStatusChanged(getSystemDestination(folderPath), resolveSyncAndErrorStatus(folderPath, NotShared));
 }
 
+void SyncFileStatusTracker::slotCheckAndRemoveSilentlyExcluded(const QString &folderPath)
+{
+    const auto foundIt = _syncSilentExcludes.find(folderPath);
+    if (foundIt != _syncSilentExcludes.end()) {
+        _syncSilentExcludes.erase(foundIt);
+        emit fileStatusChanged(getSystemDestination(folderPath), SyncFileStatus::StatusUpToDate);
+    }
+}
+
 void SyncFileStatusTracker::incSyncCountAndEmitStatusChanged(const QString &relativePath, SharedFlag sharedFlag)
 {
     // Will return 0 (and increase to 1) if the path wasn't in the map yet
@@ -231,12 +241,17 @@ void SyncFileStatusTracker::slotAboutToPropagate(SyncFileItemVector &items)
 
         if (hasErrorStatus(*item)) {
             _syncProblems[item->destination()] = SyncFileStatus::StatusError;
+            _syncSilentExcludes.erase(item->destination());
             invalidateParentPaths(item->destination());
         } else if (hasExcludedStatus(*item)) {
             _syncProblems[item->destination()] = SyncFileStatus::StatusExcluded;
+            _syncSilentExcludes.erase(item->destination());
         }
 
         SharedFlag sharedFlag = item->_remotePerm.hasPermission(RemotePermissions::IsShared) ? Shared : NotShared;
+        if (item->_instruction != CSyncEnums::CSYNC_INSTRUCTION_REMOVE) {
+            item->_discoveryResult.clear();
+        }
         if (item->_instruction != CSYNC_INSTRUCTION_NONE
             && item->_instruction != CSYNC_INSTRUCTION_UPDATE_METADATA
             && item->_instruction != CSYNC_INSTRUCTION_IGNORE
@@ -281,6 +296,7 @@ void SyncFileStatusTracker::slotItemCompleted(const SyncFileItemPtr &item)
     } else {
         _syncProblems.erase(item->destination());
     }
+    _syncSilentExcludes.erase(item->destination());
 
     SharedFlag sharedFlag = item->_remotePerm.hasPermission(RemotePermissions::IsShared) ? Shared : NotShared;
     if (item->_instruction != CSYNC_INSTRUCTION_NONE
